package cachedata

import (
	"context"
	"github.com/odysseus/cache/model"
	"github.com/stretchr/testify/assert"
	"strings"
	"testing"
)

var (
	_cache *CacheData
)

func newCache() *CacheData {
	if _cache != nil {
		return _cache
	}
	_cache = NewCacheData(context.Background(), RedisConnParam{
		Addr:     "18.167.203.17:6379",
		Password: "iH0g2CqzjI6SfercGwsT",
		DbIndex:  0,
	}, model.DbConfig{
		Host:   "18.167.203.17",
		Port:   3306,
		DbName: "ai",
		Passwd: "RFnnKHRar5xk7TEF",
		User:   "ai",
	})
	//_cache = NewCacheData(context.Background(), RedisConnParam{
	//	Addr:     "43.198.252.255:6379",
	//	Password: "iH0g2CqzjI6SfercGwsT",
	//	DbIndex:  0,
	//}, model.DbConfig{
	//	Host:   "43.198.252.255",
	//	Port:   3306,
	//	DbName: "ai",
	//	Passwd: "RFnnKHRar5xk7TEF",
	//	User:   "ai",
	//})
	return _cache
}

func TestCacheData_Query(t *testing.T) {
	cache := newCache()

	//testPath := "/txt2Img/demianhjw/aigic"
	testPath := "/predictions/agicoin/thinkdiffusionxl"
	testUid := int64(61)

	task, err := cache.Query(testPath, testUid)
	if err != nil {
		t.Error(err)
	}
	t.Log(task)
}
func TestCacheData_MQuery(t *testing.T) {
	cache := newCache()
	testPaths := []string{
		"path1",
		"path2",
		"path3",
	}
	testUids := []int64{
		1,
		2,
		3,
	}
	taskChan, err := cache.MQuery(testPaths, testUids)
	if err != nil {
		t.Error(err)
	}
	count := 0
	for task := range taskChan {
		count++
		t.Log(task)
		if count == len(testPaths) {
			break
		}
	}
}

func TestCacheData_SetUserInfo(t *testing.T) {
	cache := newCache()
	testUid := int64(1)

	user, err := cache.GetUserInfo(testUid)
	if err != nil {
		t.Error(err)
	}
	t.Log(user)
}

func TestCacheData_GetUserInfo(t *testing.T) {
	cache := newCache()
	testUid := int64(18)

	user, err := cache.GetUserInfo(testUid)
	if err != nil {
		t.Error(err)
	}
	t.Log(user)
}
func TestCacheData_UpdateUserBalance(t *testing.T) {
	cache := newCache()
	testUid := int64(1)
	testBalance := 100

	err := cache.UpdateUserBalance(testUid, testBalance)
	if err != nil {
		t.Error(err)
	}
}

func TestCacheData_UpdateUserLevel(t *testing.T) {
	cache := newCache()
	testUid := int64(1)
	testLevel := 1

	err := cache.UpdateUserLevel(testUid, testLevel)
	if err != nil {
		t.Error(err)
	}
}

func TestCacheData_UpdateUserDeleted(t *testing.T) {
	cache := newCache()
	testUid := int64(1)
	testDeleted := 1

	err := cache.UpdateUserDeleted(testUid, testDeleted)
	if err != nil {
		t.Error(err)
	}
}

func TestCacheData_UpdateUserBalanceAndLevel(t *testing.T) {
	cache := newCache()
	testUid := int64(1)
	testBalance := 100
	testLevel := 1

	// update balance first
	err := cache.UpdateUserBalance(testUid, testBalance)
	if err != nil {
		t.Error(err)
	}
	// update level second.
	err = cache.UpdateUserLevel(testUid, testLevel)
	if err != nil {
		t.Error(err)
	}
}

func TestCacheData_GetWhWithAddr(t *testing.T) {
	cache := newCache()
	testAddr := "0x84A3175be614F5886f99Da506dF08682DF530739"

	wh, err := cache.GetWhWithAddr(testAddr)
	if err != nil {
		t.Error(err)
	}
	t.Log(wh)
}

func TestCacheData_SetTaskDataToRedis(t *testing.T) {
	m := "  a  b  c   "
	tm := strings.TrimSpace(m)
	assert.Equal(t, strings.Compare(tm, "a  b  c"), 0)
}

func TestCacheData_GetUserFreeUsedInfo(t *testing.T) {
	cache := newCache()
	uids := []int64{
		61,
	}

	tids := []int64{
		1, 2, 3, 4, 5, 6, 7, 8, 9, 10,
	}

	user, err := cache.GetUserFreeUsedInfo(uids, tids)
	if err != nil {
		t.Error(err)
	}
	t.Log(user)
}
